# 2021-12-08 - Preminted BPT Meta Stable Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools have been deprecated due to numerical issues when one of the token depegs. It was superseded by this [updated version (also now deprecated)](../20221122-composable-stable-pool-v2).

Deployment of the `StablePhantomPoolFactory`, for Meta Stable Pools with preminted BPT of up to 4 tokens.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`StablePhantomPoolFactory` artifact](./artifact/StablePhantomPoolFactory.json)
